@@ -153,18 +153,12 @@ class Query:
             MySQL insert statement
         """
         cols = ",".join(["%s"] * len(kwargs)) % tuple(kwargs.keys())
-        vals = []
-        for v in kwargs.values():
-            if v != "NULL" and isinstance(v, str):
-                vals = vals + [f"'{v}'"]
-            else:
-                vals = vals + [str(v)]
-        vals = ",".join(vals)
-        que = f"INSERT INTO {table} ({cols}) VALUES ({vals})"
+        values = ",".join(["%({})s".format(i) for i in kwargs.keys()])
+        que = f"INSERT INTO {table} ({cols}) VALUES ({values})"
         return que
 
     @classmethod
-    def __update_table(cls, table: str = None, where: dict = None, **kwargs):
+    def __update_table(cls, table: str = None, where: dict = None, **kwargs) -> str:
         """\
         Build update statement.
 
@@ -176,13 +170,7 @@ class Query:
         :return
             MySQL update statement
         """
-        t = []
-        for k, v in kwargs.items():
-            if v != "NULL" and isinstance(v, str):
-                t.extend([k, f"'{v}'"])
-            else:
-                t.extend([k, str(v)])
-        cols = ",".join(["%s=%s"] * len(kwargs)) % tuple(t)
+        cols = ",".join(["{}=%({})s".format(k, k) for k in kwargs.keys()])
         key, val = [[k, v] for k, v in where.items()][0]
         que = f"UPDATE {table} SET {cols} WHERE {key}='{val}'"
         return que
@@ -204,7 +192,7 @@ class Query:
             self.__appropriatecase = isinsert
 
 
-def sampledata_sql(kwargs: dict) -> str:
+def sampledata_sql(kwargs: dict) -> None:
     """\
     A method to insert new records of samples to the database.
 
@@ -309,11 +297,11 @@ def sampledata_sql(kwargs: dict) -> str:
             )
 
         stmt = Query(isinsert=True, table="sample_data", **kargs)
-        db_connect.cur.execute(stmt.appropriate_case)
+        db_connect.cur.execute(stmt.appropriate_case, kargs)
+        print(db_connect.cur.statement)
         db_connect.cur.execute("SELECT LAST_INSERT_ID()")
         last_id = [i[0] for i in db_connect.cur.fetchall()]
         kwargs["samples"][sample]["sampleData_id"] = last_id[0]
-        print(stmt)
 
         # make insert statement for important_dates
         kargs = {
@@ -321,7 +309,7 @@ def sampledata_sql(kwargs: dict) -> str:
             "submission_date": kwargs["date_created"],
         }
         stmt = Query(isinsert=True, table="important_dates", **kargs)
-        statements.append(stmt.appropriate_case)
+        statements.append([stmt.appropriate_case, kargs])
 
         # make insert statement for sample origin
         _columns = [
@@ -350,7 +338,7 @@ def sampledata_sql(kwargs: dict) -> str:
             except KeyError:
                 pass
         stmt = Query(isinsert=True, table="sample_origin", **kargs)
-        statements.append(stmt.appropriate_case)
+        statements.append([stmt.appropriate_case, kargs])
 
         # make insert statement for hashtag barcodes
         if "hastag_parameters" in kwargs["samples"][sample]:
@@ -381,20 +369,20 @@ def sampledata_sql(kwargs: dict) -> str:
                     except KeyError:
                         pass
                 stmt = Query(isinsert=True, table="hashtags", **kargs)
-                statements.append(stmt.appropriate_case)
+                statements.append([stmt.appropriate_case, kargs])
 
     # execute all statements
-    operation = "; ".join(statements)
     try:
-        for result in db_connect.cur.execute(operation, multi=True):
-            print(result.statement)
+        for op, kargs in statements:
+            db_connect.cur.execute(op, kargs)
+            print(db_connect.cur.statement)
         db_connect.db.commit()
     except Exception as e:
         print("ERROR: " + str(e))
         print()
         db_connect.db.rollback()
 
-    return "\n".join(statements)
+    return None
 
 
 def projectdata_sql(kwargs: dict) -> str:
@@ -433,7 +421,7 @@ def projectdata_sql(kwargs: dict) -> str:
             "institution_id": institute_id,
         }
         sql = Query(isinsert=True, table="lab", **kargs)
-        db_connect.cur.execute(sql.appropriate_case)
+        db_connect.cur.execute(sql.appropriate_case, kargs)
         db_connect.cur.execute("SELECT LAST_INSERT_ID()")
         lab_id = [i[0] for i in db_connect.cur.fetchall()][0]
         db_connect.db.commit()
@@ -519,7 +507,7 @@ def projectdata_sql(kwargs: dict) -> str:
 
     sql = Query(isinsert=True, table="project_data", **kargs)
     try:
-        db_connect.cur.execute(sql.appropriate_case)
+        db_connect.cur.execute(sql.appropriate_case, kargs)
         print(db_connect.cur.statement)
         db_connect.cur.execute("SELECT LAST_INSERT_ID()")
         last_id = [i[0] for i in db_connect.cur.fetchall()]
@@ -528,7 +516,7 @@ def projectdata_sql(kwargs: dict) -> str:
             "sample_count": kwargs["Anticipated number of samples"],
         }
         sql = Query(isinsert=True, table="expected_samples", **kargs)
-        db_connect.cur.execute(sql.appropriate_case)
+        db_connect.cur.execute(sql.appropriate_case, kargs)
         print(db_connect.cur.statement)
 
         db_connect.db.commit()
@@ -579,14 +567,17 @@ def statsdata_sql(kwargs: dict) -> None:
                 "UPDATE sample_data SET genomeIndex_id = ("
                 "SELECT genome_index.id FROM genome_index "
                 "WHERE genome_index.species_id = ("
-                "SELECT id FROM species WHERE Species = '{}') "
+                "SELECT id FROM species WHERE Species = %(SPECIES)s) "
                 "AND genome_index.scTech_id = ("
-                "SELECT id FROM sc_tech WHERE sc_Tech = '{}')) "
-                "WHERE id = {}".format(
-                    kwargs["samples"][sample]["Species"], sc_Tech, _kargs[sample]
-                )
+                "SELECT id FROM sc_tech WHERE sc_Tech = %(SCTECH)s)) "
+                "WHERE id = %(SAMPLEDATA_ID)s"
             )
-            statements.append(stmt)
+            data_kargs = {
+                "SPECIES": kwargs["samples"][sample]["Species"],
+                "SCTECH": sc_Tech,
+                "SAMPLEDATA_ID": _kargs[sample],
+            }
+            statements.append([stmt, data_kargs])
         except KeyError as e:
             print("*********** ERROR *************")
             print(
@@ -622,7 +613,7 @@ def statsdata_sql(kwargs: dict) -> None:
             where={"sampleData_id": _kargs[sample]},
             **kargs,
         )
-        statements.append(stmt.appropriate_case)
+        statements.append([stmt.appropriate_case, kargs])
 
         # prepare insert statement for stats table
         kwargs["samples"][sample]["sampleIndex_id"] = get_sampleIndex(
@@ -676,13 +667,14 @@ def statsdata_sql(kwargs: dict) -> None:
             or str(kargs["QC"]) == "2"
         ):
             stmt = Query(isinsert=True, table="stats_data", **kargs)
-            statements.append(stmt.appropriate_case)
+            statements.append([stmt.appropriate_case, kargs])
         else:
             stmt_ = Query(isinsert=True, table="stats_data", **kargs)
             print(
                 "WARNING: no new data was inserted into `stats_data` table!\n\t{"
                 "}".format(stmt_)
             )
+            print(kargs)
             print("Missing `QC` and `sampleIndex_id`")
 
         if (
@@ -713,7 +705,7 @@ def statsdata_sql(kwargs: dict) -> None:
                     pass
             kargs_["Sample"] = sample + "_" + kargs_["Sample"]
             stmt = Query(isinsert=True, table="hashtag_lib", **kargs_)
-            statements.append(stmt.appropriate_case)
+            statements.append([stmt.appropriate_case, kargs_])
             # make sure all samples are able to pass the following statement
             try:
                 # in cases other than 5-prime set hto_Tech = sc_Tech + '_HashTag'
@@ -722,14 +714,17 @@ def statsdata_sql(kwargs: dict) -> None:
                     "UPDATE hashtag_lib SET genomeIndex_id = ("
                     "SELECT genome_index.id FROM genome_index "
                     "WHERE genome_index.species_id = ("
-                    "SELECT id FROM species WHERE Species = '{}') "
+                    "SELECT id FROM species WHERE Species = %(SPECIES)s) "
                     "AND genome_index.scTech_id = ("
-                    "SELECT id FROM sc_tech WHERE sc_Tech = '{}')) "
-                    "WHERE sampleData_id = {}".format(
-                        kwargs["samples"][sample]["Species"], hto_Tech, _kargs[sample]
-                    )
+                    "SELECT id FROM sc_tech WHERE sc_Tech = %(HTOTECH)s)) "
+                    "WHERE sampleData_id = %(SAMPLEDATA_ID)s"
                 )
-                statements.append(stmt)
+                data_kargs = {
+                    "SPECIES": kwargs["samples"][sample]["Species"],
+                    "HTOTECH": hto_Tech,
+                    "SAMPLEDATA_ID": _kargs[sample],
+                }
+                statements.append([stmt, data_kargs])
             except KeyError as e:
                 print("*********** ERROR *************")
                 print(
@@ -761,21 +756,24 @@ def statsdata_sql(kwargs: dict) -> None:
                     pass
             kargs_["Sample"] = sample + "_" + kargs_["Sample"]
             stmt = Query(isinsert=True, table="TCR_lib", **kargs_)
-            statements.append(stmt.appropriate_case)
+            statements.append([stmt.appropriate_case, kargs_])
             # make sure all samples are able to pass the following statement
             try:
                 stmt = (
                     "UPDATE TCR_lib SET genomeIndex_id = ("
                     "SELECT genome_index.id FROM genome_index "
                     "WHERE genome_index.species_id = ("
-                    "SELECT id FROM species WHERE Species = '{}') "
+                    "SELECT id FROM species WHERE Species = %(SPECIES)s) "
                     "AND genome_index.scTech_id = ("
-                    "SELECT id FROM sc_tech WHERE sc_Tech = '{}')) "
-                    "WHERE sampleData_id = {}".format(
-                        kwargs["samples"][sample]["Species"], tcr_Tech, _kargs[sample]
-                    )
+                    "SELECT id FROM sc_tech WHERE sc_Tech = %(TCRTECH)s)) "
+                    "WHERE sampleData_id = %(SAMPLEDATA_ID)s"
                 )
-                statements.append(stmt)
+                data_kargs = {
+                    "SPECIES": kwargs["samples"][sample]["Species"],
+                    "TCRTECH": tcr_Tech,
+                    "SAMPLEDATA_ID": _kargs[sample],
+                }
+                statements.append([stmt, data_kargs])
             except KeyError as e:
                 print("*********** ERROR *************")
                 print(
@@ -784,10 +782,10 @@ def statsdata_sql(kwargs: dict) -> None:
                 )
 
     # execute all statements
-    operation = "; ".join(statements)
     try:
-        for result in db_connect.cur.execute(operation, multi=True):
-            print(result.statement)
+        for op, kargs in statements:
+            db_connect.cur.execute(op, kargs)
+            print(db_connect.cur.statement)
         db_connect.db.commit()
     except Exception as e:
         print("ERROR: " + str(e))
