@@ -9,7 +9,7 @@ import hashlib
 import urllib.parse
 import subprocess
 import logging
-from typing import Union, Tuple, Iterable, Optional
+from typing import Union, Tuple, Iterable, Optional, Dict
 from collections import namedtuple, ChainMap
 
 import json
@@ -809,7 +809,7 @@ class JobsYmlKeys:
         claymldict = ChainMap(clayml._asdict())
         claymldict["projectId"] = str(claymldict.pop("project_id"))
         sampleName = re.search(
-            f"{claymldict['sample']}.+", claymldict.pop("old_basename")
+            f"{claymldict['sample']}.*", claymldict.pop("old_basename")
         )
         sampleName = "_".join([str(claymldict.pop("id")), sampleName.group()])
         claymldict["sampleName"] = sampleName
@@ -906,8 +906,12 @@ class JobsYmlKeys:
                 )
                 return
         except AssertionError:
-            logging.warning("Path to genomic output results is missing!")
-            return
+            logging.warning(
+                "Path to genomic output results is missing! --> [{}]".format(
+                    claymldict["id"]
+                )
+            )
+            return str(claymldict["id"])
 
         path = os.path.join(claymldict.pop("s3_loc"), claymldict["sample"], "")
         _, bucket, key, _, _ = urllib.parse.urlsplit(path)
@@ -1040,8 +1044,9 @@ def jobs_yml_config(
     instance_type: str = "r5.2xlarge",
     star_args: str = "runRNGseed=0",
     email: str = None,
-    seqcargs=None,
-) -> None:
+    seqcargs: Dict = None,
+    save: bool = True,
+) -> Optional[Dict]:
     """\
     Constructor for `yaml` formatted file for batch processing of samples.
 
@@ -1060,7 +1065,9 @@ def jobs_yml_config(
         Email address to receive run summary or errors when running remotely.
         Optional only if running locally.
     :param seqcargs:
-        Additional arguments passed to seqc
+        Additional arguments passed to seqc.
+    :param save
+        Save a copy on jobs file to path defined in config_jobs_yml, else return a copy.
 
     :return:
         `None`
@@ -1123,34 +1130,37 @@ def jobs_yml_config(
 
         jobs["jobs"].append(jobs_yml_.appropriate_case)
 
-    try:
-        assert os.path.isdir(os.path.dirname(config_jobs_yml)), ""
-        print("Jobs YAML file will be written to:\n\t\t {}".format(config_jobs_yml))
-    except AssertionError:
-        print("{:*^80}".format(" WARNING "))
-        logging.warning(
-            "{:>10}Path `{}` does not exist!".format(
-                "", os.path.dirname(config_jobs_yml)
+    if save:
+        try:
+            assert os.path.isdir(os.path.dirname(config_jobs_yml)), ""
+            print("Jobs YAML file will be written to:\n\t\t {}".format(config_jobs_yml))
+        except AssertionError:
+            print("{:*^80}".format(" WARNING "))
+            logging.warning(
+                "{:>10}Path `{}` does not exist!".format(
+                    "", os.path.dirname(config_jobs_yml)
+                )
+            )
+            logging.warning(
+                "{:>10}Try using `--tool_path [TOOL_PATH]` to override the "
+                "default path to your tool.".format("")
+            )
+            config_jobs_yml = os.path.join(
+                os.path.expanduser("~"), os.path.basename(config_jobs_yml)
+            )
+            logging.warning(
+                "{:>10}Jobs YAML will be saved to `{}`!".format("", config_jobs_yml)
             )
-        )
-        logging.warning(
-            "{:>10}Try using `--tool_path [TOOL_PATH]` to override the "
-            "default path to your tool.".format("")
-        )
-        config_jobs_yml = os.path.join(
-            os.path.expanduser("~"), os.path.basename(config_jobs_yml)
-        )
-        logging.warning(
-            "{:>10}Jobs YAML will be saved to `{}`!".format("", config_jobs_yml)
-        )
 
-    print()
-    yaml.dump(jobs, open(config_jobs_yml, "w"), sort_keys=False)
+        yaml.dump(jobs, open(config_jobs_yml, "w"), sort_keys=False)
 
-    return None
+        return None
+
+    else:
+        return jobs
 
 
-def json_hasttags(sample_data: pd.DataFrame, config_path) -> list:
+def json_hasttags(sample_data: pd.DataFrame, config_path, save: bool = True) -> list:
     """\
     Constructor for `json` formatted files for batch processing of hashtag samples.
     It Compiles `input` and `label` files for each sample in the provided data frame.
@@ -1160,6 +1170,8 @@ def json_hasttags(sample_data: pd.DataFrame, config_path) -> list:
     :param config_path:
         Path to root directory of hashtag pipeline executable `submit.sh`. It also
         serves as the parent directory for `config` where `.json` files will be written.
+    :param save
+        Save a copy on jobs file to path defined in config_jobs_yml, else return a copy.
 
     :return:
         Inputs, labels, and a list of excluded samples
@@ -1193,6 +1205,7 @@ def json_hasttags(sample_data: pd.DataFrame, config_path) -> list:
             config_path=os.path.expanduser("~/sharp-0.0.1"),
         )
     """
+    j_hash_, j_labels_ = [], []
     inputs_, labels_, exclude_ = [], [], []
     for sample in sample_data.itertuples():
         jobs_json = JobsYmlKeys(**sample._asdict())
@@ -1203,27 +1216,34 @@ def json_hasttags(sample_data: pd.DataFrame, config_path) -> list:
             j_labels = jobs_json.appropriate_case.maps[1]
             inputs = jobs_json.appropriate_case["inputs"]
             labels = jobs_json.appropriate_case["labels"]
-            with open(os.path.join(config_path, inputs), "w") as f:
-                f.write(json.dumps(j_hash, indent=4))
-                f.close()
-            with open(os.path.join(config_path, labels), "w") as f:
-                f.write(json.dumps(j_labels, indent=4))
-                f.close()
-            print(
-                "Inputs and labels json files were written to:\n\t\t {}".format(
-                    os.path.join(config_path, "config")
+            if save:
+                with open(os.path.join(config_path, inputs), "w") as f:
+                    f.write(json.dumps(j_hash, indent=4))
+                    f.close()
+                with open(os.path.join(config_path, labels), "w") as f:
+                    f.write(json.dumps(j_labels, indent=4))
+                    f.close()
+                print(
+                    "Inputs and labels json files were written to:\n\t\t {}".format(
+                        os.path.join(config_path, "config")
+                    )
                 )
-            )
-            # write tag-list to AWS
-            hres = jobs_json.appropriate_case["hres"]
-            tag_list = jobs_json.appropriate_case["tag_list"]
-            f = hres.to_csv(header=False, index=False)
-            s3 = boto3.resource("s3")
-            _, bucket, key, _, _ = urllib.parse.urlsplit(tag_list)
-            obj = s3.Object(bucket, key.strip("/"))
-            obj.put(Body=f.encode())
+                # write tag-list to AWS
+                hres = jobs_json.appropriate_case["hres"]
+                tag_list = jobs_json.appropriate_case["tag_list"]
+                f = hres.to_csv(header=False, index=False)
+                s3 = boto3.resource("s3")
+                _, bucket, key, _, _ = urllib.parse.urlsplit(tag_list)
+                obj = s3.Object(bucket, key.strip("/"))
+                obj.put(Body=f.encode())
+            else:
+                j_hash_.append(j_hash)
+                j_labels_.append(j_labels)
 
             inputs_.append(inputs)
             labels_.append(labels)
 
-    return [zip(inputs_, labels_), exclude_]
+    if save:
+        return [zip(inputs_, labels_), exclude_]
+    else:
+        return [zip(inputs_, labels_, j_hash_, j_labels_), exclude_]
