@@ -14,6 +14,7 @@ from typing import Tuple
 
 import pandas as pd
 import boto3
+import regex
 from botocore.exceptions import ClientError
 from tabulate import tabulate
 
@@ -53,10 +54,18 @@ def make_credentials(
     shuffle(password)
     password = "".join(password)
     iam_ = boto3.client("iam")
-    iam_.create_user(
-        UserName=user,
-        Tags=[{"Key": "Name", "Value": name}, {"Key": "email", "Value": email}],
-    )
+    try:
+        iam_.create_user(
+            UserName=user,
+            Tags=[{"Key": "Name", "Value": name}, {"Key": "email", "Value": email}],
+        )
+    except ClientError as err:
+        user = regex.findall("[\p{L}\p{Z}\p{N}_.:/=+\-@]*", user)
+        user = "".join(user)
+        iam_.create_user(
+            UserName=user,
+            Tags=[{"Key": "Name", "Value": name}, {"Key": "email", "Value": email}],
+        )
     iam_.add_user_to_group(GroupName=groupname, UserName=user)
     key_response = iam_.create_access_key(UserName=user)
     iam_.create_login_profile(
